"""Helper functinos for dealing with dicts.

Things you always wished you could do more succinctly!
"""
from .limited_dict import LimitedDict
from .chained_dict import ChainedDict
from .helpers import *
